import { Controller, Get, Param, Query } from '@nestjs/common';
import { OrdersService } from './orders.service';
import { PreOrdersService } from './pre-orders.service';
import { ProductsService } from '../products/products.service';
import { Order } from './order.entity';

@Controller('orders')
export class OrdersController {
  constructor(
    private readonly ordersService: OrdersService,
    private productsService: ProductsService,
    private preOrdersService: PreOrdersService,
  ) {}

  @Get('all')
  async getAllOrders() {
    const userId = 1;
    const results = await this.ordersService.getAll(userId);
    const ordersObj = results.map((t) => ({
      ...t,
      items: JSON.parse(t.items),
    }));
    const ids = ordersObj.flatMap((t) => t.items).map((t) => t.id);
    const products = await this.productsService.getProducts(ids);
    const orders: Order[] = [];
    ordersObj.forEach((order) => {
      const items: any[] = [];
      order.items.forEach((t) => {
        const fnd = products.find((p) => p.id === t.id);
        if (fnd)
          items.push({
            id: fnd.id,
            imageUrl: fnd.imageUrl,
            title: fnd.title,
            price: fnd.price,
            quantity: t.quantity,
          });
      });
      const newOrderObj: Order = {
        id: order.id,
        userId: order.userId,
        paymentIntentId: order.paymentIntentId,
        orderDate: order.orderDate,
        items: JSON.stringify(items),
        total: order.total,
        transObjId: order.transObjId,
        labelUrl: order.labelUrl,
        trackingNumber: order.trackingNumber,
        trackingUrl: order.trackingUrl,
      };
      orders.push(newOrderObj);
    });

    return orders;
  }

  @Get(':id')
  getOrder(@Param('id') orderId) {
    const userId = 1;
    return this.ordersService.getOrderById(userId, orderId);
  }

  roundNumber(v: number) {
    return Math.round((v + Number.EPSILON) * 100) / 100;
  }
}
