import { Injectable, NotFoundException } from '@nestjs/common';
import { PaymentIntent } from './payment-intent.entity';
import { v4 as uuidv4 } from 'uuid';

@Injectable()
export class PaymentIntentsService {
  private paymentIntents: PaymentIntent[] = [];

  createPaymentIntent(paymentIntentId: string, preOrderId: string) {
    const id = uuidv4();
    const newPaymentIntent = {
      id,
      preOrderId,
      paymentIntentId,
    };
    this.paymentIntents.push(newPaymentIntent);
    return Promise.resolve(newPaymentIntent);
  }

  findOneByPaymentIntentId(paymentIntentId: string) {
    if (!paymentIntentId) {
      throw new NotFoundException(
        "Can't find a payment intent with the id: ",
        paymentIntentId,
      );
    }
    return Promise.resolve(
      this.paymentIntents.find(
        (paymentIntent) => paymentIntent.paymentIntentId == paymentIntentId,
      ),
    );
  }

  delete(paymentIntentId: string) {
    this.paymentIntents = this.paymentIntents.filter(
      (paymentIntent) => paymentIntent.paymentIntentId != paymentIntentId,
    );
    return Promise.resolve(this.paymentIntents);
  }
}
