import { Injectable } from '@nestjs/common';
import { config } from 'dotenv';

config();

@Injectable()
export class StripeService {
  async checkout(preorder, headers) {
    const stripe = require('stripe')(`${process.env.STRIPE_SECRET_KEY}`);
    const lineItems = [];

    const items = JSON.parse(preorder.items);
    items.forEach((item) => {
      const unit_amount = Math.round(item.price * 100);
      const lineItem = {
        price_data: {
          currency: 'usd',
          product_data: {
            name: item.name,
            images: [item.imageUrl],
          },
          unit_amount,
        },
        quantity: item.quantity,
      };
      lineItems.push(lineItem);
    });

    const session = await stripe.checkout.sessions.create({
      payment_method_types: ['card'],
      shipping_options: [
        {
          shipping_rate_data: {
            type: 'fixed_amount',
            fixed_amount: {
              amount: preorder.rate.amount * 100,
              currency: preorder.rate.currency,
            },
            display_name:
              preorder.rate.provider + ', ' + preorder.rate.servicelevel.name,
            delivery_estimate: {
              minimum: {
                unit: 'business_day',
                value: preorder.rate.estimatedDays,
              },
              maximum: {
                unit: 'business_day',
                value: preorder.rate.estimatedDays + 1,
              },
            },
          },
        },
      ],
      line_items: lineItems,
      mode: 'payment',
      success_url: headers.origin + '/success',
      cancel_url: headers.origin + '/cancel',
      metadata: {
        preOrderId: preorder.id,
      },
    });

    return { id: session.id };
  }
}
